@@ -1,16 +1,13 @@
-from typing import List, Dict
+from typing import List
 
-from zero_ex.contract_wrappers import TxParams
-
-from .base import BaseModule
-from ..types.metadata import Metadata
-from ..types.nft import NftMetadata
-from ..errors import NoSignerException
-from ..types.role import Role
-from ..abi.nft_collection import NFTCollection
 from web3 import Web3
 
-from ..types.collection import CollectionMetadata, CreateCollectionArg, MintCollectionArg
+from ..abi.nft_collection import NFTCollection
+from ..types.collection import (CollectionMetadata, CreateCollectionArg,
+                                MintCollectionArg)
+from ..types.metadata import Metadata
+from ..types.nft import NftMetadata
+from .base import BaseModule
 
 
 class CollectionModule(BaseModule):
@@ -40,12 +37,14 @@ class CollectionModule(BaseModule):
     '''
     Returns the balance for a given token at owned by a specific address
     '''
+
     def balance_of(self, address: str, token_id: int) -> int:
         return self.__abi_module.balance_of.call(address, token_id)
 
     '''
     Returns the balance for a given token id for the current signers address
     '''
+
     def balance(self, token_id: int) -> int:
         return self.__abi_module.balance_of.call(
             self.get_signer_address(),
@@ -72,30 +71,35 @@ class CollectionModule(BaseModule):
         return self.create_batch([metadata])[0]
 
     def create_batch(self, metas: List[Metadata]) -> List[CollectionMetadata]:
-        meta_with_supply = [CreateCollectionArg(metadata=m, supply=0) for m in metas]
+        meta_with_supply = [CreateCollectionArg(
+            metadata=m, supply=0) for m in metas]
         return self.create_and_mint_batch(meta_with_supply)
 
     def create_and_mint(self, meta_with_supply: CreateCollectionArg) -> CollectionMetadata:
         return self.create_and_mint_batch([meta_with_supply])[0]
 
     def create_and_mint_batch(self, meta_with_supply: List[CreateCollectionArg]) -> List[CollectionMetadata]:
-        uris = [self.get_storage().upload(meta.to_json(), self.address, self.get_signer_address()) for meta in meta_with_supply]
+        uris = [self.get_storage().upload(meta.to_json(), self.address,
+                                          self.get_signer_address()) for meta in meta_with_supply]
         supplies = [a.supply for a in meta_with_supply]
         receipt = self.execute_tx(self.__abi_module.create_native_tokens.build_transaction(
             self.get_signer_address(), uris, supplies, "", self.get_transact_opts()
         ))
-        result = self.__abi_module.get_native_tokens_event(tx_hash=receipt.transactionHash.hex())
+        result = self.__abi_module.get_native_tokens_event(
+            tx_hash=receipt.transactionHash.hex())
         token_ids = result[0]['args']['tokenIds']
         return [self.get(i) for i in token_ids]
 
     def create_with_erc20(self, token_contract: str, token_amount: int, arg: CreateCollectionArg):
-        uri = self.get_storage().upload(arg.metadata, self.address, self.get_signer_address())
+        uri = self.get_storage().upload(
+            arg.metadata, self.address, self.get_signer_address())
         self.execute_tx(self.__abi_module.wrap_erc20.build_transaction(
             token_contract, token_amount, arg.supply, uri, self.get_transact_opts()
         ))
 
     def create_with_erc721(self, token_contract: str, token_id: int, metadata):
-        uri = self.get_storage().upload(metadata.metadata, self.address, self.get_signer_address())
+        uri = self.get_storage().upload(
+            metadata.metadata, self.address, self.get_signer_address())
         self.execute_tx(self.__abi_module.wrap_erc721.build_transaction(
             token_contract, token_id, uri, self.get_transact_opts()
         ))
@@ -131,7 +135,8 @@ class CollectionModule(BaseModule):
 
     def burn_batch_from(self, account: str, args: List[MintCollectionArg]):
         self.execute_tx(self.__abi_module.burn_batch.build_transaction(
-            account, [i.id for i in args], [i.amount for i in args], self.get_transact_opts()
+            account, [i.id for i in args], [
+                i.amount for i in args], self.get_transact_opts()
         ))
 
     def transfer_from(self, from_address: str, to_address: str, args: MintCollectionArg):
@@ -149,39 +154,5 @@ class CollectionModule(BaseModule):
             amount, self.get_transact_opts()
         ))
 
-    def grant_role(self, role: Role, address: str):
-        role_hash = role.get_hash()
-        self.execute_tx(self.__abi_module.grant_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
-        ))
-
-    def revoke_role(self, role: Role, address: str):
-        role_hash = role.get_hash()
-
-        try:
-            signer_address = self.get_signer_address()
-            if signer_address.lower() != address.lower():
-                pass
-            self.execute_tx(self.__abi_module.renounce_role.build_transaction(
-                role_hash, address, self.get_transact_opts()
-            ))
-            return
-        except NoSignerException:
-            pass
-
-        self.execute_tx(self.__abi_module.revoke_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
-        ))
-
-    def get_role_members(self, role: Role) -> List[str]:
-        role_hash = role.get_hash()
-        count = self.__abi_module.get_role_member_count.call(role_hash)
-        return [self.__abi_module.get_role_member.call(role_hash, i) for i in range(count)]
-
-    def get_all_role_members(self) -> Dict[Role, List[str]]:
-        return {
-            Role.admin.name: self.get_role_members(Role.admin),
-            Role.minter.name: self.get_role_members(Role.minter),
-            Role.transfer.name: self.get_role_members(Role.transfer),
-            Role.pauser.name: self.get_role_members(Role.pauser)
-        }
+    def get_abi_module(self) -> NFTCollection:
+        return self.__abi_module
