@@ -1,17 +1,14 @@
 """ Interact with the NFT module of the app"""
 import copy
-
 import json
+from typing import Dict, List
 
 from web3 import Web3
-from zero_ex.contract_wrappers import TxParams
 
-from .base import BaseModule
-from typing import Dict, List
 from ..abi.nft import NFT
-
-from ..types import Role
-from ..types.nft import MintArg, NftMetadata as NftType
+from ..types.nft import MintArg
+from ..types.nft import NftMetadata as NftType
+from .base import BaseModule
 
 
 class NftModule(BaseModule):
@@ -33,7 +30,6 @@ class NftModule(BaseModule):
         """
         return self.mint_to(self.get_signer_address(), arg)
 
-
     def mint_to(
             self,
             to_address: str,
@@ -56,8 +52,10 @@ class NftModule(BaseModule):
             'properties': final_properties
         }
 
-        uri = storage.upload(json.dumps(meta), self.address, self.get_signer_address())
-        tx = self.__abi_module.mint_nft.build_transaction(to_address, uri, self.get_transact_opts())
+        uri = storage.upload(json.dumps(meta), self.address,
+                             self.get_signer_address())
+        tx = self.__abi_module.mint_nft.build_transaction(
+            to_address, uri, self.get_transact_opts())
         receipt = self.execute_tx(tx)
         result = self.__abi_module.get_minted_event(
             tx_hash=receipt.transactionHash.hex())
@@ -70,22 +68,22 @@ class NftModule(BaseModule):
         """
         return self.__abi_module.total_supply.call()
 
-    def get(self, nft_id: int) -> NftType:
+    def get(self, token_id: int) -> NftType:
         """
         Returns the Metadata of a token
         """
-        uri = self.__get_metadata_uri(nft_id)
+        uri = self.__get_metadata_uri(token_id)
         meta = self.get_storage().get(uri)
         meta_obj: NftType = NftType.from_json(meta)
-        meta_obj.id = nft_id
+        meta_obj.id = token_id
         meta_obj.uri = uri
         return meta_obj
 
-    def __get_metadata_uri(self, nft_id: int):
+    def __get_metadata_uri(self, token_id: int):
         """
         Returns the uri of the metadata of a token
         """
-        uri = self.__abi_module.token_uri.call(nft_id)
+        uri = self.__abi_module.token_uri.call(token_id)
         if uri == "":
             raise Exception(
                 "Could not find NFT metadata, are you sure it exists?")
@@ -97,7 +95,6 @@ class NftModule(BaseModule):
         """
         return self.mint_batch_to(self.get_signer_address(), args)
 
-
     def mint_batch_to(self, to_address: str, args: List[MintArg]):
         """
         Mints a batch of tokens to the given address
@@ -112,7 +109,6 @@ class NftModule(BaseModule):
         tx = self.__abi_module.mint_nft_batch.build_transaction(
             to_address, uris, self.get_transact_opts())
 
-
         receipt = self.execute_tx(tx)
         result = self.__abi_module.get_minted_batch_event(
             tx_hash=receipt.transactionHash.hex())
@@ -191,7 +187,6 @@ class NftModule(BaseModule):
         """
         return self.__abi_module.balance_of.call(self.get_signer_address())
 
-
     def balance_of(self, address: str) -> int:
         """
         Returns balance of the given address
@@ -225,32 +220,10 @@ class NftModule(BaseModule):
         """
         Sets approval for specified operator, defaults to grant approval
         """
-        tx = self.__abi_module.set_approval_for_all.build_transaction(operator, approved, self.get_transact_opts() )
+        tx = self.__abi_module.set_approval_for_all.build_transaction(
+            operator, approved, self.get_transact_opts())
         self.execute_tx(tx)
 
-
-    def grant_role(self, role: Role, address: str):
-        """
-        Grants the given role to the given address
-        """
-
-        role_hash = role.get_hash()
-        tx = self.__abi_module.grant_role.build_transaction(
-            role_hash, address,
-            self.get_transact_opts()
-        )
-        self.execute_tx(tx)
-
-
-    def revoke_role(self, role: Role, address: str):
-        """
-        Revokes the given role from the given address
-        """
-        role_hash = role.get_hash()
-        self.execute_tx(self.__abi_module.revoke_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
-        ))
-
     def set_restricted_transfer(self, restricted: bool = True):
         self.execute_tx(self.__abi_module.set_restricted_transfer.build_transaction(
             restricted, self.get_transact_opts()
@@ -267,12 +240,15 @@ class NftModule(BaseModule):
             meta: meta
         }
 
-    def set_module_metadata(metadata: str):
+    def set_module_metadata(self, metadata: str):
         """
         Sets the metadata for the module
         """
         uri = self.get_storage().upload_metadata(
             metadata, self.address, self.get_signer_address())
+        tx = self.__abi_module.set_contract_uri.build_transaction(
+            uri, self.get_transact_opts())
+        self.execute_tx(tx)
 
     def set_restricted_transfer(self, restricted: bool = False):
         """
@@ -283,31 +259,5 @@ class NftModule(BaseModule):
             restricted, self.get_transact_opts())
         self.execute_tx(tx)
 
-    def get_role_member_count(self, role: Role):
-        """
-        Returns the number of members in the given role
-        """
-        return self.__abi_module.get_role_member_count.call(role.get_hash())
-
-    def get_role_members(self, role: Role):
-        """
-        Returns the members of the given role
-        """
-        return [self.get_role_member(role, x) for x in range(self.get_role_member_count(role))]
-
-    def get_role_member(self, role: Role, index: int):
-        """
-        Returns the member at the given index of the given role
-        """
-        return self.__abi_module.get_role_member.call(role.get_hash(), index)
-
-    def get_all_role_members(self):
-        """
-        Returns all the members of all the roles
-        """
-        return {
-            "admin": [item for item in self.get_role_members(Role.admin)],
-            "transfer": [item for item in self.get_role_members(Role.transfer)],
-            "minter": [item for item in self.get_role_members(Role.minter)],
-            "pauser": [item for item in self.get_role_members(Role.pauser)],
-        }
+    def get_abi_module(self) -> NFT:
+        return self.__abi_module
