@@ -1,13 +1,19 @@
-from ..errors import NoSignerException, AssetNotFoundException
-from ..types import Role
-from ..types.pack import PackMetadata, PackNftMetadata, CreatePackArg, AssetAmountPair
-from ..types.nft import NftMetadata
-from ..types.currency import Currency, CurrencyValue
-from ..abi.pack import Pack
-from .base import BaseModule
-from ..abi.erc20 import ERC20
+from datetime import datetime
+from typing import Dict, List
+from json import dumps
+
 from web3 import Web3
-from typing import List, Dict
+from eth_abi import encode_abi
+
+
+from ..abi.erc1155 import ERC1155
+from ..abi.pack import Pack
+from ..errors import AssetNotFoundException, UnsupportedAssetException
+from ..types.currency import CurrencyValue
+from ..types.nft import NftMetadata
+from ..types.pack import (AssetAmountPair, CreatePackArg, PackMetadata,
+                          PackNftMetadata)
+from .base import BaseModule
 
 
 class PackModule(BaseModule):
@@ -20,17 +26,27 @@ class PackModule(BaseModule):
         self.__abi_module = Pack(client, address)
 
     def get(self, pack_id: int) -> PackMetadata:
-        uri = self.__abi_module.token_uri.call(pack_id)
+        uri = self._BaseModule__get_token_uri(pack_id)
         if uri == "":
             raise AssetNotFoundException(pack_id)
         metadata = self.get_storage().get(uri)
-        return None
+        state = self.__abi_module.get_pack.call(pack_id)
+        total_supply = self.__abi_module.total_supply.call(pack_id)
+        return PackMetadata(
+            id=pack_id,
+            creator_address=state.creator,
+            current_supply=total_supply,
+            metadata=metadata,
+            open_start=None if state.openStart <= 0 else datetime.fromtimestamp(
+                state.openStart),
+        )
 
     def open(self, pack_id: int) -> List[NftMetadata]:
         pass
 
     def get_all(self) -> List[PackMetadata]:
-        pass
+        max_id = self.__abi_module.next_token_id.call()
+        return [self.get(i) for i in range(max_id)]
 
     def get_nfts(self, pack_id: int) -> List[PackNftMetadata]:
         pass
@@ -55,7 +71,33 @@ class PackModule(BaseModule):
         ))
 
     def create(self, arg: CreatePackArg) -> PackMetadata:
-        pass
+        """
+        WIP: This method is not ready to be called.
+
+        Suffers from same issue as MarketModule.list
+        """
+
+        if not self.is_erc1155(arg.asset_contract_address):
+            raise UnsupportedAssetException(arg.asset_contract_address)
+
+        asset_contract = ERC1155(
+            self.get_client(), arg.asset_contract_address)
+        from_address = self.get_signer_address()
+        ids = [a.token_id for a in arg.assets]
+        amounts = [a.amount for a in arg.assets]
+        uri = self.get_storage().upload(
+            dumps(arg.metadata), self.address, self.get_signer_address())
+
+        params = encode_abi(
+            ['string', 'uint256', 'uint256'],
+            [uri, arg.seconds_until_open_start, arg.rewards_per_open]
+        )
+
+        receipt = self.execute_tx(asset_contract.safe_batch_transfer_from.build_transaction(
+            from_address, self.address, ids, amounts, params, self.get_transact_opts(),
+        ))
+        result = self.__abi_module.get_pack_created_event(
+            receipt.transactionHash)
 
     def transfer_from(self, from_address: str, to_address: str, args: AssetAmountPair):
         return self.execute_tx(self.__abi_module.safe_transfer_from.build_transaction(
@@ -69,12 +111,21 @@ class PackModule(BaseModule):
         ))
 
     def get_link_balance(self) -> CurrencyValue:
+        """
+        WIP: This method is not ready to be called.
+        """
         pass
 
     def deposit_link(self, amount: int):
+        """
+        WIP: This method is not ready to be called.
+        """
         pass
 
     def withdraw_link(self, to_address: str, amount: int):
+        """
+        WIP: This method is not ready to be called.
+        """
         pass
 
     def set_royalty_bps(self, amount: int):
@@ -87,39 +138,5 @@ class PackModule(BaseModule):
             restricted, self.get_transact_opts()
         ))
 
-    def grant_role(self, role: Role, address: str):
-        role_hash = role.get_hash()
-        self.execute_tx(self.__abi_module.grant_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
-        ))
-
-    def revoke_role(self, role: Role, address: str):
-        role_hash = role.get_hash()
-
-        try:
-            signer_address = self.get_signer_address()
-            if signer_address.lower() != address.lower():
-                pass
-            self.execute_tx(self.__abi_module.renounce_role.build_transaction(
-                role_hash, address, self.get_transact_opts()
-            ))
-            return
-        except NoSignerException:
-            pass
-
-        self.execute_tx(self.__abi_module.revoke_role.build_transaction(
-            role_hash, address, self.get_transact_opts()
-        ))
-
-    def get_role_members(self, role: Role) -> List[str]:
-        role_hash = role.get_hash()
-        count = self.__abi_module.get_role_member_count.call(role_hash)
-        return [self.__abi_module.get_role_member.call(role_hash, i) for i in range(count)]
-
-    def get_all_role_members(self) -> Dict[Role, List[str]]:
-        return {
-            Role.admin.name: self.get_role_members(Role.admin),
-            Role.minter.name: self.get_role_members(Role.minter),
-            Role.transfer.name: self.get_role_members(Role.transfer),
-            Role.pauser.name: self.get_role_members(Role.pauser)
-        }
+    def get_abi_module(self) -> Pack:
+        return self.__abi_module
