@@ -40,3 +40,7 @@ class IpfsStorage:
 
         response = result.json()
         return response['IpfsUri']
+    
+    def upload_metadata(self, metadata: str, contract_address: str, signer_address: str) -> str:
+        if type(metadata) == str:
+            return self.upload(metadata, contract_address, signer_address)
